==> 0.0.1.tar.gz: ios/Classes/SwiftOinPosPlugin.swift <==
import Flutter
import UIKit

public class SwiftOinPosPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "oin_pos_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftOinPosPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "testPrint":
      testPrint { (success) in
        result(success)
      }
    case "connectBluetooth":
      Communication.connectBluetooth { (success, title, message) in
        result(success)
      }
//      result(connectBluetooth())
//      let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
//      let commands = ApiFunctions.createPeripheralData(emulation)
//      if let args = call.arguments as? Dictionary<String, Any> {
//        let data = try! JSONSerialization.data(withJSONObject: args, options: [])
//        let receipts = try! JSONDecoder().decode(Receipts.self, from: data)
//        print(receipts)
//      }
//      sendCommands(commands)
    case "openCashDrawer":
      openCashDrawer()
    case "searchPort":
      searchPort()
    case "currentPort":
      result(currentPort())
    default:
      break
    }
  }
  
  func testPrint(completionHandler: @escaping (Bool) -> ()) {
    let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
    let commands = ApiFunctions.append3inchTextReceiptData(emulation)
    sendCommands(commands) { (success) in
      completionHandler(success)
    }
  }
  
  func openCashDrawer() {
    let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
    let commands = ApiFunctions.createPeripheralData(emulation)
    sendCommands(commands) { (success) in
      
    }
  }
  
  func currentPort() -> String {
    CustomDelegate.settingManager.load()
    if CustomDelegate.settingManager.settings[0] == nil {
      return "沒有連接任何Port"
    }else {
      let currentSetting = CustomDelegate.settingManager.settings[0]!
      return currentSetting.portName
    }
  }
  
  func searchPort() {
    let keyWindow = UIApplication.shared.windows.filter {$0.isKeyWindow}.first
    if var topController = keyWindow?.rootViewController {
      while let presentedViewController = topController.presentedViewController {
        topController = presentedViewController
      }
      let vc = PortListController()
      let nav = UINavigationController(rootViewController: vc)
      nav.modalPresentationStyle = .fullScreen
      topController.present(nav, animated: true, completion: nil)
    }
  }
  
  fileprivate func sendCommands(_ commands: Data?, handler: @escaping (Bool) -> ()) {
    CustomDelegate.settingManager.load()
    let portName:     String = CustomDelegate.getPortName()
    let portSettings: String = CustomDelegate.getPortSettings()
    
    GlobalQueueManager.shared.serialQueue.async {
      _ = Communication.sendCommands(commands,
                                     portName: portName,
                                     portSettings: portSettings,
                                     timeout: 10000,
                                     completionHandler: { (communicationResult: CommunicationResult) in
                                      if communicationResult.result == .success {
                                        handler(true)
                                      }else {
                                        handler(false)
                                      }
      })
    }
  }
}

==> 0.0.3.tar.gz: ios/Classes/SwiftOinPosPlugin.swift <==
import Flutter
import UIKit

struct Receipts: Decodable {
  let storeName: String
  let invoiceNumber: String
  let orders: [Order]
  let total: String
}

struct Order: Decodable {
  let name: String
  let combo: [String]?
  let amount: Int
  let price: String
}

extension Order {
  var height: Int {
    if let combo = combo {
      return (30 * combo.count) + 40
    }
    return 30
  }
}

public class SwiftOinPosPlugin: NSObject, FlutterPlugin {
  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "oin_pos_plugin", binaryMessenger: registrar.messenger())
    let instance = SwiftOinPosPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
    case "testPrint":
      testPrint { (success) in
        result(success)
      }
    case "connectBluetooth":
      Communication.connectBluetooth { (success, title, message) in
        result(success)
      }
    case "openCashDrawer":
      openCashDrawer()
    case "searchPort":
      searchPort()
    case "currentPort":
      result(currentPort())
    case "printReceipts":
      let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
      if let args = call.arguments as? Dictionary<String, Any> {
        let data = try! JSONSerialization.data(withJSONObject: args, options: [])
        let receipts = try! JSONDecoder().decode(Receipts.self, from: data)
        let commands = ApiFunctions.createReceipts(emulation, receipts: receipts)
        sendCommands(commands) { (success) in
          result(success)
        }
      }
    default:
      break
    }
  }
  
  func testPrint(completionHandler: @escaping (Bool) -> ()) {
    let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
    let commands = ApiFunctions.append3inchTextReceiptData(emulation)
    sendCommands(commands) { (success) in
      completionHandler(success)
    }
  }
  
  func openCashDrawer() {
    let emulation: StarIoExtEmulation = CustomDelegate.getEmulation()
    let commands = ApiFunctions.createPeripheralData(emulation)
    sendCommands(commands) { (success) in
      
    }
  }
  
  func currentPort() -> String {
    CustomDelegate.settingManager.load()
    if CustomDelegate.settingManager.settings[0] == nil {
      return "沒有連接任何Port"
    }else {
      let currentSetting = CustomDelegate.settingManager.settings[0]!
      return currentSetting.portName
    }
  }
  
  func searchPort() {
    let keyWindow = UIApplication.shared.windows.filter {$0.isKeyWindow}.first
    if var topController = keyWindow?.rootViewController {
      while let presentedViewController = topController.presentedViewController {
        topController = presentedViewController
      }
      let vc = PortListController()
      let nav = UINavigationController(rootViewController: vc)
      nav.modalPresentationStyle = .fullScreen
      topController.present(nav, animated: true, completion: nil)
    }
  }
  
  fileprivate func sendCommands(_ commands: Data?, handler: @escaping (Bool) -> ()) {
    CustomDelegate.settingManager.load()
    let portName:     String = CustomDelegate.getPortName()
    let portSettings: String = CustomDelegate.getPortSettings()
    
    GlobalQueueManager.shared.serialQueue.async {
      _ = Communication.sendCommands(commands,
                                     portName: portName,
                                     portSettings: portSettings,
                                     timeout: 10000,
                                     completionHandler: { (communicationResult: CommunicationResult) in
                                      if communicationResult.result == .success {
                                        handler(true)
                                      }else {
                                        handler(false)
                                      }
      })
    }
  }
}
